pub struct PropertyValueTypeFlags(/* private fields */);Expand description
A set of property value type flags (PropValTypeFlag_*).
A bitmask, not an enumeration: the engine combines flags, and a caller must be able to express “number or string”.
use rs_teststand::PropertyValueTypeFlags as Flags;
let numeric_or_text = Flags::NUMBER | Flags::STRING;
assert!(numeric_or_text.contains(Flags::STRING));
assert!(!numeric_or_text.contains(Flags::CONTAINER));Implementations
Sourceimpl PropertyValueTypeFlags
impl PropertyValueTypeFlags
Sourcepub const NAMED_TYPE: Self
pub const NAMED_TYPE: Self
Named type instance (PropValTypeFlag_NamedType).
Sourcepub const BOOLEAN_ARRAY: Self
pub const BOOLEAN_ARRAY: Self
Boolean array (PropValTypeFlag_BooleanArray).
Sourcepub const NUMBER_ARRAY: Self
pub const NUMBER_ARRAY: Self
Numeric array (PropValTypeFlag_NumberArray).
Sourcepub const STRING_ARRAY: Self
pub const STRING_ARRAY: Self
String array (PropValTypeFlag_StringArray).
Sourcepub const REFERENCE_ARRAY: Self
pub const REFERENCE_ARRAY: Self
Reference array (PropValTypeFlag_ReferenceArray).
Sourcepub const CONTAINER_ARRAY: Self
pub const CONTAINER_ARRAY: Self
Container array (PropValTypeFlag_ContainerArray).
Sourcepub const ARRAY_OF_NAMED_TYPE: Self
pub const ARRAY_OF_NAMED_TYPE: Self
Array of a named type (PropValTypeFlag_ArrayOfNamedType).
Sourcepub const PLAIN_REFERENCE: Self
pub const PLAIN_REFERENCE: Self
Plain reference (PropValTypeFlag_PlainReference).
Sourcepub const PLAIN_CONTAINER: Self
pub const PLAIN_CONTAINER: Self
Plain container (PropValTypeFlag_PlainContainer).
Sourceimpl PropertyValueTypeFlags
impl PropertyValueTypeFlags
Sourcepub const fn bits(&self) -> i32
pub const fn bits(&self) -> i32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: i32) -> Option<Self>
pub const fn from_bits(bits: i32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: i32) -> Self
pub const fn from_bits_truncate(bits: i32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: i32) -> Self
pub const fn from_bits_retain(bits: i32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl PropertyValueTypeFlags
impl PropertyValueTypeFlags
Sourcepub const fn iter(&self) -> Iter<PropertyValueTypeFlags>
pub const fn iter(&self) -> Iter<PropertyValueTypeFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<PropertyValueTypeFlags>
pub const fn iter_names(&self) -> IterNames<PropertyValueTypeFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.