Module execution

Module execution 

Running sequences.

Re-exports

pub use execution::Execution;
pub use result_list::ResultList;
pub use result_list::ResultValue;
pub use result_list::StepResult;
pub use sequence_context::SequenceContext;

Modules

execution
A running sequence.
result_list
Reading an execution’s recorded results.
sequence_context
The variable scopes and run state visible from a point in a running sequence.

Structs

Thread
A thread within an Execution.

Enums

ThreadTerminationOption
What a thread does when its execution is asked to terminate (ThreadTerminationOptions).