Module sequence_context

Module sequence_context 

The variable scopes and run state visible from a point in a running sequence.

Structs

SequenceContext
A point in a running sequence, and everything reachable from it (SequenceContext).