pub struct GetSeqFileOptions(/* private fields */);Expand description
Flags for opening a sequence file (GetSeqFile_*).
use rs_teststand::GetSeqFileOptions as Options;
let opened = Options::PRELOAD_MODULES | Options::FIND_FILE;
assert!(opened.contains(Options::FIND_FILE));Implementations
Sourceimpl GetSeqFileOptions
impl GetSeqFileOptions
Sourcepub const PRELOAD_MODULES: Self
pub const PRELOAD_MODULES: Self
Preload the file’s code modules (GetSeqFile_PreloadModules).
Sourcepub const UPDATE_FROM_DISK: Self
pub const UPDATE_FROM_DISK: Self
Reload from disk even if cached (GetSeqFile_UpdateFromDisk).
Sourcepub const ALLOW_TYPE_CONFLICTS: Self
pub const ALLOW_TYPE_CONFLICTS: Self
Tolerate type conflicts (GetSeqFile_AllowTypeConflicts).
Sourcepub const DO_NOT_RUN_LOAD_CALLBACK: Self
pub const DO_NOT_RUN_LOAD_CALLBACK: Self
Skip the file’s load callback (GetSeqFile_DoNotRunLoadCallback).
A load callback can display a dialog, which blocks an unattended host, set this when opening untrusted files headlessly.
Sourcepub const FIND_FILE: Self
pub const FIND_FILE: Self
Search the configured directories for the file (GetSeqFile_FindFile).
Sourcepub const OPERATOR_INTERFACE: Self
pub const OPERATOR_INTERFACE: Self
The combination an operator interface uses
(GetSeqFile_OperatorInterfaceFlags).
Sourcepub const ONLY_IF_IN_CACHE: Self
pub const ONLY_IF_IN_CACHE: Self
Return the file only if already cached
(GetSeqFile_GetFileOnlyIfInCache).
Sourceimpl GetSeqFileOptions
impl GetSeqFileOptions
Sourcepub const fn bits(&self) -> i32
pub const fn bits(&self) -> i32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: i32) -> Option<Self>
pub const fn from_bits(bits: i32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: i32) -> Self
pub const fn from_bits_truncate(bits: i32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: i32) -> Self
pub const fn from_bits_retain(bits: i32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl GetSeqFileOptions
impl GetSeqFileOptions
Sourcepub const fn iter(&self) -> Iter<GetSeqFileOptions>
pub const fn iter(&self) -> Iter<GetSeqFileOptions>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<GetSeqFileOptions>
pub const fn iter_names(&self) -> IterNames<GetSeqFileOptions>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.