The variable scopes and run state visible from a point in a running sequence.
Structs
- Sequence
Context - A point in a running sequence, and everything reachable from it
(
SequenceContext).
The variable scopes and run state visible from a point in a running sequence.
SequenceContext).